@@ -7,11 +7,9 @@ from scipy.ndimage import interpolation as inter
 import easyocr
 
 class OcrMeter:
-    def __init__(self, num_digit, meter_type) -> None:
+    def __init__(self) -> None:
         self.paddleocr = PaddleOCR(use_angle_cls="False", lang="en", show_log=False)
         self.easyocr = easyocr.Reader(['en'],gpu="False")
-        self.num_digit = num_digit + 1
-        self.meter_type = meter_type
     
     def cal_expand_point(self, x1, y1, x2, y2, length):
         dx = x1-x2
@@ -67,24 +65,25 @@ class OcrMeter:
                 borderMode=cv2.BORDER_REPLICATE)
         return corrected
 
-    def inference_single(self, img_path):
+    def inference_single(self, img_path, num_digit, meter_type):
+        num_digit = num_digit + 1
         output = {}
         img = cv2.imread(img_path)
         h, w, _ = img.shape
         img = img[int(h/4):int(h-h/4), int(w/5.5):int(w-w/5.5), :]
         img = self.correct_skew(img)
-        if self.meter_type == "water" or self.meter_type == "electricity":
+        if meter_type == "water" or meter_type == "electricity":
             result = self.paddleocr.ocr(img, det=True, cls=False)
             # print(result)
             result = result[-1]
             for i in range(len(result)):
                 ocr_res = "".join(re.findall(r"\d+", result[i][1][0]))
                 box = result[i][0]
-                if len(ocr_res) == self.num_digit and ocr_res.isdigit():
+                if len(ocr_res) == num_digit and ocr_res.isdigit():
                     output["black_digits"] = ocr_res[:-1]
                     output["red_digit"] = ocr_res[-1]
                     break
-                if len(ocr_res) == self.num_digit - 1 and ocr_res.isdigit():
+                if len(ocr_res) == num_digit - 1 and ocr_res.isdigit():
 
                     for j in range(len(result)):
                         if i == j:
@@ -96,12 +95,12 @@ class OcrMeter:
                             and result[j][1][0].isdigit()
                         ):
                             ocr_res += result[j][1][0]
-                    if len(ocr_res) == self.num_digit:
+                    if len(ocr_res) == num_digit:
                         output["black_digits"] = ocr_res[:-1]
                         output["red_digit"] = ocr_res[-1]
                         break
 
-                    length = int((box[1][0] - box[0][0]) / (self.num_digit-1))
+                    length = int((box[1][0] - box[0][0]) / (num_digit-1))
                     x1, y1 = box[1]
                     x2, y2 = box[2]
                     box[1], box[2] = self.cal_expand_point(x1, y1, x2, y2, length)
@@ -113,32 +112,32 @@ class OcrMeter:
                     
                     result_crop = self.paddleocr.ocr(img_crop, det=False, cls=False)
                     digits = "".join(re.findall(r"\d+", result_crop[0][0][0]))
-                    if len(digits) > self.num_digit:
-                        output["black_digits"] = digits[:self.num_digit-1]
-                        output["red_digit"] = digits[self.num_digit-1]
+                    if len(digits) > num_digit:
+                        output["black_digits"] = digits[:num_digit-1]
+                        output["red_digit"] = digits[num_digit-1]
                         break
-                    elif len(digits) == self.num_digit:
+                    elif len(digits) == num_digit:
                         output["black_digits"] = digits[:-1]
                         output["red_digit"] = digits[-1]
                         break
                     else:
                         while True:
                             digits += "x"
-                            if len(digits) >= self.num_digit:
+                            if len(digits) >= num_digit:
                                 break
                         output["black_digits"] = digits[:-1]
                         output["red_digit"] = digits[-1]
                         break
-        elif self.meter_type == "gas":
+        elif meter_type == "gas":
             result = self.easyocr.readtext(img)
             for i in range(len(result)):
                 ocr_res = "".join(re.findall(r"\d+", result[i][1]))
                 box = result[i][0]
-                if len(ocr_res) == self.num_digit and ocr_res.isdigit():
+                if len(ocr_res) == num_digit and ocr_res.isdigit():
                     output["black_digits"] = ocr_res[:-1]
                     output["red_digit"] = ocr_res[-1]
                     break
-                if len(ocr_res) >= self.num_digit - 3 and len(ocr_res) <= self.num_digit - 1 and ocr_res.isdigit():
+                if len(ocr_res) >= num_digit - 3 and len(ocr_res) <= num_digit - 1 and ocr_res.isdigit():
                     for j in range(len(result)):
                         if i == j:
                             continue
@@ -149,12 +148,12 @@ class OcrMeter:
                             and result[j][1][0].isdigit()
                         ):
                             ocr_res += result[j][1][0]
-                    if len(ocr_res) == self.num_digit:
+                    if len(ocr_res) == num_digit:
                         output["black_digits"] = ocr_res[:-1]
                         output["red_digit"] = ocr_res[-1]
                         break
 
-                    lack_digits = self.num_digit - len(ocr_res)
+                    lack_digits = num_digit - len(ocr_res)
                     length = int(((box[1][0] - box[0][0]) / lack_digits) * lack_digits) + 10
                     x1, y1 = box[1]
                     x2, y2 = box[2]
@@ -168,18 +167,18 @@ class OcrMeter:
                     result_crop = self.easyocr.recognize(img_crop)
 
                     digits = "".join(re.findall(r"\d+", result_crop[0][1]))
-                    if len(digits) > self.num_digit:
-                        output["black_digits"] = digits[:self.num_digit-1]
-                        output["red_digit"] = digits[self.num_digit-1]
+                    if len(digits) > num_digit:
+                        output["black_digits"] = digits[:num_digit-1]
+                        output["red_digit"] = digits[num_digit-1]
                         break
-                    elif len(digits) == self.num_digit:
+                    elif len(digits) == num_digit:
                         output["black_digits"] = digits[:-1]
                         output["red_digit"] = digits[-1]
                         break
                     else:
                         while True:
                             digits += "x"
-                            if len(digits) >= self.num_digit:
+                            if len(digits) >= num_digit:
                                 break
                         output["black_digits"] = digits[:-1]
                         output["red_digit"] = digits[-1]
